@@ -17,13 +17,15 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import logging
+import socket
 import typing
 import unittest.mock
 
-import _pytest.logging
+import _pytest.logging  # pylint: disable=import-private-name; typing
 import pytest
 from paho.mqtt.client import MQTT_ERR_QUEUE_SIZE, MQTT_ERR_SUCCESS, MQTTMessage, Client
 
+# pylint: disable=import-private-name; internal
 import switchbot_mqtt
 import switchbot_mqtt._actors
 from switchbot_mqtt._actors import _ButtonAutomator, _CurtainMotor
@@ -34,6 +36,69 @@ from switchbot_mqtt._utils import _MQTTTopicLevel, _MQTTTopicPlaceholder
 # pylint: disable=too-many-arguments; these are tests, no API
 
 
+@pytest.mark.parametrize(
+    ("socket_family", "peername", "peername_log"),
+    [
+        (socket.AF_INET, ("mqtt-broker.local", 1883), "mqtt-broker.local:1883"),
+        # https://github.com/fphammerle/switchbot-mqtt/issues/42#issuecomment-1173909335
+        (socket.AF_INET6, ("::1", 1883, 0, 0), "[::1]:1883"),
+    ],
+)
+def test__mqtt_on_connect(
+    caplog: _pytest.logging.LogCaptureFixture,
+    socket_family: int,  # socket.AddressFamily,
+    peername: typing.Tuple[typing.Union[str, int]],
+    peername_log: str,
+) -> None:
+    mqtt_client = unittest.mock.MagicMock()
+    mqtt_client.socket().family = socket_family
+    mqtt_client.socket().getpeername.return_value = peername
+    with caplog.at_level(logging.DEBUG):
+        switchbot_mqtt._mqtt_on_connect(
+            mqtt_client,
+            _MQTTCallbackUserdata(
+                retry_count=3,
+                device_passwords={},
+                fetch_device_info=False,
+                mqtt_topic_prefix="whatever/",
+            ),
+            {},
+            0,
+        )
+    mqtt_client.publish.assert_called_once_with(
+        topic="whatever/switchbot-mqtt/status", payload="online", retain=True
+    )
+    assert mqtt_client.subscribe.call_args_list == [
+        unittest.mock.call("whatever/switch/switchbot/+/set"),
+        unittest.mock.call("whatever/cover/switchbot-curtain/+/set"),
+        unittest.mock.call("whatever/cover/switchbot-curtain/+/position/set-percent"),
+    ]
+    assert mqtt_client.message_callback_add.call_count == 3
+    assert caplog.record_tuples == [
+        (
+            "switchbot_mqtt",
+            logging.DEBUG,
+            "connected to MQTT broker " + peername_log,
+        ),
+        (
+            "switchbot_mqtt._actors.base",
+            logging.INFO,
+            "subscribing to MQTT topic 'whatever/switch/switchbot/+/set'",
+        ),
+        (
+            "switchbot_mqtt._actors.base",
+            logging.INFO,
+            "subscribing to MQTT topic 'whatever/cover/switchbot-curtain/+/set'",
+        ),
+        (
+            "switchbot_mqtt._actors.base",
+            logging.INFO,
+            "subscribing to MQTT topic "
+            "'whatever/cover/switchbot-curtain/+/position/set-percent'",
+        ),
+    ]
+
+
 @pytest.mark.parametrize("mqtt_host", ["mqtt-broker.local"])
 @pytest.mark.parametrize("mqtt_port", [1833])
 @pytest.mark.parametrize("retry_count", [3, 21])
@@ -76,6 +141,9 @@ def test__run(
     )
     assert not mqtt_client_mock().username_pw_set.called
     mqtt_client_mock().tls_set.assert_called_once_with(ca_certs=None)
+    mqtt_client_mock().will_set.assert_called_once_with(
+        topic="homeassistant/switchbot-mqtt/status", payload="offline", retain=True
+    )
     mqtt_client_mock().connect.assert_called_once_with(host=mqtt_host, port=mqtt_port)
     mqtt_client_mock().socket().getpeername.return_value = (mqtt_host, mqtt_port)
     with caplog.at_level(logging.DEBUG):
