@@ -16,19 +16,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+# pylint: disable=protected-access
+# pylint: disable=too-many-arguments; these are tests, no API
+# pylint: disable=duplicate-code; similarities with tests for curtain motor
+
 import logging
 import typing
 import unittest.mock
 
-import _pytest.logging
+import _pytest.logging  # pylint: disable=import-private-name; typing
 import bluepy.btle
 import pytest
 
+# pylint: disable=import-private-name; internal
 from switchbot_mqtt._actors import _ButtonAutomator
 
-# pylint: disable=protected-access
-# pylint: disable=too-many-arguments; these are tests, no API
-
 
 @pytest.mark.parametrize("prefix", ["homeassistant/", "prefix-", ""])
 @pytest.mark.parametrize("mac_address", ["{MAC_ADDRESS}", "aa:bb:cc:dd:ee:ff"])
